@@ -7,7 +7,7 @@ stop, and wait on jobs.
 """
 
 #
-# Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008 The SCons Foundation
+# Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013 The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -29,13 +29,14 @@ stop, and wait on jobs.
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #
 
-__revision__ = "src/engine/SCons/Job.py 3266 2008/08/12 07:31:01 knight"
+__revision__ = "src/engine/SCons/Job.py  2013/03/03 09:48:35 garyo"
 
 import SCons.compat
 
 import os
 import signal
 
+import SCons.Errors
 
 # The default stack size (in kilobytes) of the threads used to execute
 # jobs in parallel.
@@ -45,12 +46,13 @@ import signal
 # parallelized the build. For example, the default stack size on linux
 # is 8 MBytes.
 
+explicit_stack_size = None
 default_stack_size = 256
 
 interrupt_msg = 'Build interrupted.'
 
 
-class InterruptState:
+class InterruptState(object):
    def __init__(self):
        self.interrupted = False
 
@@ -61,7 +63,7 @@ class InterruptState:
        return self.interrupted
 
 
-class Jobs:
+class Jobs(object):
     """An instance of this class initializes N jobs, and provides
     methods for starting, stopping, and waiting on all N jobs.
     """
@@ -82,9 +84,8 @@ class Jobs:
 
         self.job = None
         if num > 1:
-            try:
-                stack_size = SCons.Job.stack_size
-            except AttributeError:
+            stack_size = explicit_stack_size
+            if stack_size is None:
                 stack_size = default_stack_size
                 
             try:
@@ -128,7 +129,7 @@ class Jobs:
         turns out that it very difficult to stop the build process
         by throwing asynchronously an exception such as
         KeyboardInterrupt. For example, the python Condition
-        variables (threading.Condition) and Queue's do not seem to
+        variables (threading.Condition) and queue's do not seem to
         asynchronous-exception-safe. It would require adding a whole
         bunch of try/finally block and except KeyboardInterrupt all
         over the place.
@@ -162,7 +163,7 @@ class Jobs:
         except AttributeError:
             pass
 
-class Serial:
+class Serial(object):
     """This class is used to execute tasks in series, and is more efficient
     than Parallel, but is only appropriate for non-parallel builds. Only
     one instance of this class should be in existence at a time.
@@ -188,7 +189,7 @@ class Serial:
         fails to execute (i.e. execute() raises an exception), then the job will
         stop."""
         
-        while 1:
+        while True:
             task = self.taskmaster.next_task()
 
             if task is None:
@@ -222,7 +223,7 @@ class Serial:
 # Parallel class (and its dependent classes) will work if the interpreter
 # doesn't support threads.
 try:
-    import Queue
+    import queue
     import threading
 except ImportError:
     pass
@@ -241,10 +242,10 @@ else:
             self.start()
 
         def run(self):
-            while 1:
+            while True:
                 task = self.requestQueue.get()
 
-                if not task:
+                if task is None:
                     # The "None" value is used as a sentinel by
                     # ThreadPool.cleanup().  This indicates that there
                     # are no more tasks, so we should quit.
@@ -263,7 +264,7 @@ else:
 
                 self.resultsQueue.put((task, ok))
 
-    class ThreadPool:
+    class ThreadPool(object):
         """This class is responsible for spawning and managing worker threads."""
 
         def __init__(self, num, stack_size, interrupted):
@@ -272,21 +273,20 @@ else:
             One must specify the stack size of the worker threads. The
             stack size is specified in kilobytes.
             """
-            self.requestQueue = Queue.Queue(0)
-            self.resultsQueue = Queue.Queue(0)
+            self.requestQueue = queue.Queue(0)
+            self.resultsQueue = queue.Queue(0)
 
             try:
                 prev_size = threading.stack_size(stack_size*1024) 
             except AttributeError, e:
                 # Only print a warning if the stack size has been
-                # explicitely set.
-                if hasattr(SCons.Job, 'stack_size'):
+                # explicitly set.
+                if not explicit_stack_size is None:
                     msg = "Setting stack size is unsupported by this version of Python:\n    " + \
                         e.args[0]
                     SCons.Warnings.warn(SCons.Warnings.StackSizeWarning, msg)
             except ValueError, e:
-                msg = "Setting stack size failed:\n    " + \
-                    e.message
+                msg = "Setting stack size failed:\n    " + str(e)
                 SCons.Warnings.warn(SCons.Warnings.StackSizeWarning, msg)
 
             # Create worker threads
@@ -295,9 +295,7 @@ else:
                 worker = Worker(self.requestQueue, self.resultsQueue, interrupted)
                 self.workers.append(worker)
 
-            # Once we drop Python 1.5 we can change the following to:
-            #if 'prev_size' in locals():
-            if 'prev_size' in locals().keys():
+            if 'prev_size' in locals():
                 threading.stack_size(prev_size)
 
         def put(self, task):
@@ -340,7 +338,7 @@ else:
                 worker.join(1.0)
             self.workers = []
 
-    class Parallel:
+    class Parallel(object):
         """This class is used to execute tasks in parallel, and is somewhat 
         less efficient than Serial, but is appropriate for parallel builds.
 
@@ -376,7 +374,7 @@ else:
 
             jobs = 0
             
-            while 1:
+            while True:
                 # Start up as many available tasks as we're
                 # allowed to.
                 while jobs < self.maxjobs:
@@ -404,7 +402,7 @@ else:
 
                 # Let any/all completed tasks finish up before we go
                 # back and put the next batch of tasks on the queue.
-                while 1:
+                while True:
                     task, ok = self.tp.get()
                     jobs = jobs - 1
 
@@ -429,3 +427,9 @@ else:
 
             self.tp.cleanup()
             self.taskmaster.cleanup()
+
+# Local Variables:
+# tab-width:4
+# indent-tabs-mode:nil
+# End:
+# vim: set expandtab tabstop=4 shiftwidth=4:
