@@ -8,8 +8,7 @@ selection method.
 
 """
 
-#
-# Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008 The SCons Foundation
+# Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013 The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -29,9 +28,8 @@ selection method.
 # LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 # OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
-#
 
-__revision__ = "src/engine/SCons/Tool/SCCS.py 3266 2008/08/12 07:31:01 knight"
+__revision__ = "src/engine/SCons/Tool/SCCS.py  2013/03/03 09:48:35 garyo"
 
 import SCons.Action
 import SCons.Builder
@@ -43,6 +41,8 @@ def generate(env):
 
     def SCCSFactory(env=env):
         """ """
+        import SCons.Warnings as W
+        W.warn(W.DeprecatedSourceCodeWarning, """The SCCS() factory is deprecated and there is no replacement.""")
         act = SCons.Action.Action('$SCCSCOM', '$SCCSCOMSTR')
         return SCons.Builder.Builder(action = act, env = env)
 
@@ -56,3 +56,9 @@ def generate(env):
 
 def exists(env):
     return env.Detect('sccs')
+
+# Local Variables:
+# tab-width:4
+# indent-tabs-mode:nil
+# End:
+# vim: set expandtab tabstop=4 shiftwidth=4:
